Learn R Programming

faviconPlease (version 0.1.4)

faviconDuckDuckGo: Use DuckDuckGo's favicon service

Description

The search engine DuckDuckGo includes site favicons in its search results, and it makes this service publicly available. If it can't find a favicon, it returns a default fallback. faviconPlease uses this as a fallback function if the favicon can't be found directly via the standard methods.

Usage

faviconDuckDuckGo(server)

Value

Character vector

Arguments

server

The name of the server, e.g. "www.r-project.org"

References

DuckDuckGo favicons privacy

See Also

faviconPlease, faviconGoogle

Examples

Run this code
  faviconDuckDuckGo("reactome.org")

Run the code above in your browser using DataLab