Check for the existence of favicon.ico
faviconIco(
scheme,
server,
path,
method = getOption("download.file.method", default = "auto"),
extra = getOption("download.file.extra"),
headers = NULL
)URL to favicon.ico or "".
"http" or "https"
The name of the server, e.g. "www.r-project.org"
The path to a target file on the server (must start with a forward slash)
Method to be used for downloading files. Current
download methods are "internal", "libcurl",
"wget", "curl" and "wininet" (Windows
only), and there is a value "auto": see ‘Details’ and
‘Note’.
The method can also be set through the option
"download.file.method": see options().
character vector of additional command-line arguments for
the "wget" and "curl" methods.
named character vector of additional HTTP headers to
use in HTTP[S] requests. It is ignored for non-HTTP[S] URLs. The
User-Agent header taken from the HTTPUserAgent option
(see options) is automatically used as the first header.
faviconPlease,
faviconLink