Learn R Programming

faviconPlease (version 0.1.4)

faviconLink: Search for a link element that specifies the location of the favicon

Description

Search for a link element that specifies the location of the favicon

Usage

faviconLink(scheme, server, path)

Value

URL to favicon or "".

Arguments

scheme

"http" or "https"

server

The name of the server, e.g. "www.r-project.org"

path

The path to a target file on the server (must start with a forward slash)

See Also

faviconPlease, faviconIco