powered by
Search for a link element that specifies the location of the favicon
faviconLink(scheme, server, path)
URL to favicon or "".
""
"http" or "https"
The name of the server, e.g. "www.r-project.org"
The path to a target file on the server (must start with a forward slash)
faviconPlease, faviconIco
faviconPlease
faviconIco